@@ -10,11 +10,12 @@ describe 'swift::client' do
     { :package_ensure   => 'present' }
   end
 
-  shared_examples_for 'swift client' do
+  shared_examples 'swift::client' do
     let :p do
       default_params.merge(params)
     end
 
+    it { is_expected.to contain_class('swift::deps') }
     it { is_expected.to contain_class('swift::params') }
 
     it 'installs swift client package' do
@@ -40,17 +41,13 @@ describe 'swift::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-swiftclient' }
-          else
-            { :client_package_name => 'python-swiftclient' }
-          end
+          { :client_package_name => 'python3-swiftclient' }
         when 'RedHat'
           { :client_package_name => 'python-swiftclient' }
         end
       end
 
-      it_configures 'swift client'
+      it_configures 'swift::client'
     end
   end
 
